Prepare the docbooks for the 1.4 branch.
[metze/wireshark/wip.git] / summary.h
index e417fef6937817c5481b2e7fd35f4088aa330936..ef32e7b64e12907fd9e8c650f2c1289697876f38 100644 (file)
--- a/summary.h
+++ b/summary.h
@@ -3,8 +3,8 @@
  *
  * $Id$
  *
- * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@ethereal.com>
+ * Wireshark - Network traffic analyzer
+ * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +26,6 @@
 #define __SUMMARY_H__
 
 #ifdef HAVE_LIBPCAP
-#include <pcap.h>
 #include "capture.h"
 #endif
 
@@ -38,13 +37,18 @@ typedef struct _summary_tally {
                                   includes time before first packet
                                   and after last packet */
     int                marked_count;   /* number of marked packets */
+    guint64    marked_bytes;   /* total bytes in the marked packets */
+    double     marked_start;   /* time in seconds, with msec resolution */
+    double     marked_stop;    /* time in seconds, with msec resolution */
+    int                ignored_count;  /* number of ignored packets */
     int                packet_count;   /* total number of packets in trace */
     int                filtered_count; /* number of filtered packets */
     guint64    filtered_bytes; /* total bytes in the filtered packets */
     double     filtered_start; /* time in seconds, with msec resolution */
     double     filtered_stop;  /* time in seconds, with msec resolution */
     const char *filename;
-    long       file_length;    /* file length in bytes */
+    gint64     file_length;    /* file length in bytes */
+    int                file_type;      /* wiretap file type */
     int                encap_type;     /* wiretap encapsulation type */
     gboolean   has_snap;       /* TRUE if maximum capture packet length is known */
     int                snap;           /* Maximum captured packet length */
@@ -58,7 +62,7 @@ typedef struct _summary_tally {
     const char *iface_descr;/* descriptive interface name */
 } summary_tally;
 
-extern void 
+extern void
 summary_fill_in(capture_file *cf, summary_tally *st);
 
 #ifdef HAVE_LIBPCAP